@@ -109,7 +109,11 @@ namespace SDDM {
         Session::Type sessionType = Session::X11Session;
 
         // determine session type
-        const QString &autologinSession = mainConfig.Autologin.Session.get();
+        QString autologinSession = mainConfig.Autologin.Session.get();
+        // not configured: try last successful logged in
+        if (autologinSession.isEmpty()) {
+            autologinSession = stateConfig.Last.Session.get();
+        }
         if (findSessionEntry(mainConfig.X11.SessionDir.get(), autologinSession)) {
             sessionType = Session::X11Session;
         } else if (findSessionEntry(mainConfig.Wayland.SessionDir.get(), autologinSession)) {
@@ -140,7 +144,7 @@ namespace SDDM {
         qDebug() << "Display server started.";
 
         if ((daemonApp->first || mainConfig.Autologin.Relogin.get()) &&
-            !mainConfig.Autologin.User.get().isEmpty() && !mainConfig.Autologin.Session.get().isEmpty()) {
+            !mainConfig.Autologin.User.get().isEmpty()) {
             // reset first flag
             daemonApp->first = false;
 
